@@ -53,13 +53,29 @@ from typing import (
 
 # 3rd party
 import pydash  # type: ignore
-from typing_extensions import Protocol
 
 # this package
 from domdf_python_tools.doctools import prettify_docstrings
+from domdf_python_tools.typing import SupportsIndex
 
-__all__ = ["Dictable", "NamedList", "namedlist", "UserList", "UserFloat"]
+__all__ = [
+		"Dictable",
+		"NamedList",
+		"namedlist",
+		"UserList",
+		"UserFloat",
+		"Lineup",
+		"_V",
+		"_LU",
+		"_T",
+		"_S",
+		"_F",
+		]
 
+_F = TypeVar("_F", bound="UserFloat")
+_LU = TypeVar("_LU", bound="Lineup")
+_S = TypeVar("_S", bound="UserList")
+_T = TypeVar("_T")
 _V = TypeVar("_V")
 
 
@@ -110,10 +126,6 @@ class Dictable(Iterable[Tuple[str, _V]]):
 		return NotImplemented
 
 
-_T = TypeVar("_T")
-_S = TypeVar("_S", bound="UserList")
-
-
 @prettify_docstrings
 class UserList(MutableSequence[_T]):
 	"""
@@ -357,15 +369,6 @@ class UserList(MutableSequence[_T]):
 			self.data.extend(other)
 
 
-class _SupportsIndex(Protocol):
-
-	def __index__(self) -> int:
-		...
-
-
-_F = TypeVar("_F", bound="UserFloat")
-
-
 @prettify_docstrings
 class UserFloat(Real):
 	"""
@@ -376,21 +379,39 @@ class UserFloat(Real):
 	.. versionadded:: 1.6.0
 	"""
 
-	def __init__(self, value: Union[SupportsFloat, _SupportsIndex, str, bytes, bytearray] = 0.0):
+	def __init__(self, value: Union[SupportsFloat, SupportsIndex, str, bytes, bytearray] = 0.0):
 		self._value = (float(value), )
 
 	def as_integer_ratio(self) -> Tuple[int, int]:
+		"""
+		Returns the float as a fraction.
+		"""
+
 		return float(self).as_integer_ratio()
 
-	def hex(self) -> str:
+	def hex(self) -> str:  # noqa: A003
+		"""
+		Returns the hexadecimal (base 16) representation of the float.
+		"""
+
 		return float(self).hex()
 
 	def is_integer(self) -> bool:
+		"""
+		Returns whether the float is an integer.
+		"""
+
 		return float(self).is_integer()
 
 	@classmethod
-	def fromhex(cls: Type[_F], __s: str) -> _F:
-		return cls(float.fromhex(__s))
+	def fromhex(cls: Type[_F], string: str) -> _F:
+		"""
+		Create a floating-point number from a hexadecimal string.
+
+		:param string:
+		"""
+
+		return cls(float.fromhex(string))
 
 	def __add__(self: _F, other: float) -> _F:
 		return self.__class__(float(self).__add__(other))
@@ -444,6 +465,10 @@ class UserFloat(Real):
 		return self._value
 
 	def __trunc__(self) -> int:
+		"""
+		Truncates the float to an integer.
+		"""
+
 		return float(self).__trunc__()
 
 	def __round__(self, ndigits: Optional[int] = None) -> Union[int, float]:  # type: ignore
@@ -515,6 +540,22 @@ class UserFloat(Real):
 	def __floor__(self):
 		raise NotImplementedError
 
+	def __bool__(self) -> bool:
+		"""
+		Return ``self != 0``.
+		"""
+
+		return super().__bool__()
+
+	def __complex__(self) -> complex:
+		"""
+		Returrn :func:`complex(self) <complex>``.
+
+		``complex(self) == complex(float(self), 0)``
+		"""
+
+		return super().__complex__()
+
 
 @prettify_docstrings
 class NamedList(UserList[_T]):
@@ -548,3 +589,79 @@ def namedlist(name: str = "NamedList") -> Type[NamedList]:
 	cls.__name__ = name
 
 	return cls
+
+
+class Lineup(UserList[_T]):
+	"""
+	List-like type with fluent methods and some star players.
+	"""
+
+	def replace(self: _LU, what: _T, with_: _T) -> _LU:
+		r"""
+		Replace the first instance of ``what`` with ``with_``.
+
+		:param what: The object to find and replace.
+		:param with\_: The new value for the position in the list.
+		"""
+
+		self[self.index(what)] = with_
+
+		return self
+
+	def sort(  # type: ignore
+			self: _LU,
+			*,
+			key=None,
+			reverse: bool = False,
+			) -> _LU:
+		"""
+		Sort the list in ascending order and return the self.
+
+		The sort is in-place (i.e. the list itself is modified) and stable (i.e. the
+		order of two equal elements is maintained).
+
+		If a key function is given, apply it once to each list item and sort them,
+		ascending or descending, according to their function values.
+
+		The reverse flag can be set to sort in descending order.
+		"""
+
+		super().sort(key=key, reverse=reverse)
+		return self
+
+	def reverse(self: _LU) -> _LU:  # type: ignore  # noqa: D102
+		super().reverse()
+		return self
+
+	def append(  # type: ignore  # noqa: D102
+			self: _LU,
+			item: _T,
+			) -> _LU:
+		super().append(item)
+		return self
+
+	def extend(  # type: ignore# noqa: D102
+			self: _LU,
+			other: Iterable[_T],
+			) -> _LU:
+		super().extend(other)
+		return self
+
+	def insert(  # type: ignore  # noqa: D102
+			self: _LU,
+			i: int,
+			item: _T,
+			) -> _LU:
+		super().insert(i, item)
+		return self
+
+	def remove(  # type: ignore  # noqa: D102
+			self: _LU,
+			item: _T,
+			) -> _LU:
+		super().remove(item)
+		return self
+
+	def clear(self: _LU) -> _LU:  # type: ignore  # noqa: D102
+		super().clear()
+		return self
